#!/bin/bash
# This script installs vsoagent as a systemd service

servicename="codespaces.service"

echo "Installing Service $servicename ..."

# Set execuctable basepath for the service
sed "s|{BITS_DIR}|`pwd`|g" codespaces.service > /etc/systemd/system/codespaces.service

cp codespaces vso

# Set permissions for the Unit file and executable
chmod 644 /etc/systemd/system/codespaces.service
# BACKWARDS COMPATIBILITY
chmod +x vso
chmod +x codespaces
chmod +x vsls-agent
chmod +x sourcer.sh
chmod +x sourcer.zsh
chmod +x Docker/linux-prereqs.sh

# Create folder so that the agent uses the new one instead of falling back to the old one.
mkdir -p /root/.codespaces/shared
chmod -R 777 /root/.codespaces

# Install credential manager in VM
git config --system --add credential.helper '/.codespaces/agent/bin/codespaces gitCredential'

# Reload damoen since Unit file is new/modified
systemctl daemon-reload  

# Enable service to start on boot
systemctl enable /etc/systemd/system/codespaces.service
rc=$?
if [ $rc -ne 0 ]
then
	echo "Service $servicename failed to install!"
	exit $rc
fi

isEnabled=`systemctl is-enabled $servicename`
if [ "$isEnabled" == "enabled" ]
then
	echo "Service $servicename has been successfully installed!"
	echo "Run following command to start the service"
	echo "sudo systemctl start $servicename"
else
	echo "Failed to enable service after installation";
	exit 1
fi

